@@ -9,13 +9,13 @@
 
 #include <QDebug>
 
-#include <collectionfetchjob.h>
-#include <collectionfetchscope.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include "akonadi/kmime/messageparts.h"
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 using namespace Akonadi;
 
